Introduction
------------

A simple interface to pick points on a geometry file (e.g. stl, ply, obj, etc.) and to export the coordinates to a csv file.


Installation
------------

The package can be installed with pip.

.. code-block:: bash

   $ pip install point-picker-3d
   

Example Usage
-------------

>>> python main.py

.. image:: examples/example_1.PNG
   :width: 600
